@@ -1,7 +1,7 @@
 package Terminal::Identify;
 
 # Load the basic Perl pragmas.
-use 5.026000;
+use 5.010100;
 use strict;
 use warnings;
 
@@ -23,7 +23,7 @@ our @EXPORT = qw(
 our @ISA = qw(Exporter);
 
 # Set the package version.
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 
 # Load the Perl modules.
 use POSIX qw(ttyname);
@@ -105,10 +105,15 @@ if (! -e $FN_SHELLS) {
 # ++++++++++++++++++++++++++++++++++++++++++
 # Create a dictionary from __DATA__ section.
 # ++++++++++++++++++++++++++++++++++++++++++
+
+# Initialise some variables. 
 my $line = "";
 my $key = "";
 my $value = "";
+
+# Read data from __DATA__ section.
 while (<DATA>) {
+    # Read data only between the two given boundaries.
     if (/# Begin terminals/../# End terminals/) {
         next if /# Begin terminals/ || /# End terminals/;
         $line = $_;
@@ -186,16 +191,14 @@ sub read_file {
     # Initialise the return variable.
     my $content = "";
     # If file not exists, return an empty string.
-    if (! -f $file) {
-        # Return an empty string.
-        return $content;
+    if (-f $file) {
+        # Open a file handler for reading the file.
+        open(my $fh, "<", $file);
+        # Read the complete content from the file.
+        $content = do {local $/; <$fh>};
+        # Close the file handler.
+        close($fh);
     };
-    # Open a file handler for reading the file.
-    open(my $fh, "<", $file);
-    # Read the complete content from the file.
-    $content = do {local $/; <$fh>};
-    # Close the file handler.
-    close($fh);
     # Return the file content.
     return $content;
 };
@@ -210,10 +213,15 @@ sub read_file {
 # @return:   $user_arr  Array with the logged-in users  (array)                #
 # ============================================================================ #
 sub login_users {
-    # Get the logged-in users from Linux command users.
+    # Initialise the return array.
+    my @user_array = (); 
+    # Get the logged-in users from the Linux command users.
     my $user = `users`;
-    # Split the logged-in users and store them to the array.
-    my @user_array = split ' ', $user;
+    # Check if the variable $user is defined and not empty.
+    if (defined $user && $user ne "") {
+        # Split the logged-in users and store them to the array.
+        @user_array = split ' ', $user;
+    };
     # Return the array with the logged-in users.
     return @user_array;
 };
@@ -591,6 +599,8 @@ sub get_terminal_ftn {
     my $terminal_name = $_[0];
     # Initialise the return variable.
     my $terminal_ftn = "";
+    # Convert terminal name to lower case.
+    $terminal_name = lc($terminal_name);
     # Check terminal name.
     if (defined $termhash{$terminal_name}) {
         # Get the friendly terminal name.
@@ -665,6 +675,12 @@ sub whichterminalami {
 
 __DATA__
 
+# Some of the terminal emulators listed below were tested with the package in
+# the test environment, or are generally known as terminal emulators, or come
+# from other sources. Care was taken to ensure that the executable and the
+# publicly used name match. Without further tests, the latter statement is to
+# be seen relatively. The list cannot claim to be complete.
+
 # Begin terminals
 ajaxterm                => AjaxTerm
 alacritty               => Alacritty
@@ -683,13 +699,13 @@ conemu                  => ConEmu
 contour                 => Contour Terminal
 coolterm                => CoolTerm
 cool-retro-term         => Cool Retro Term
-cutecom                 => CuteCome
+cutecom                 => CuteCom
 deepin-terminal         => Deepin Terminal
 domterm                 => DomTerm
 dterm                   => dterm
 dtterm                  => dtterm
 edex-ui                 => eDEX-UI
-Eterm                   => Eterm
+eterm                   => Eterm
 extraterm               => Extraterm
 fbpad                   => Fbpad
 fbterm                  => Fbterm
@@ -719,6 +735,7 @@ mlterm                  => mlterm
 mlterm-tiny             => mlterm-tiny
 mrxvt                   => mrxvt
 netterm                 => NetTerm
+noter                   => NoTer
 okidk                   => OkiDK
 pantheon-terminal       => Pantheon Terminal
 picocom                 => PicoCom
@@ -726,7 +743,9 @@ pterm                   => pterm
 powershell              => PowerShell
 powerterm               => PowerTerm
 putty                   => PuTTY
+qtterm                  => QtTerm
 qterminal               => QTerminal
+realterm                => RealTerm
 rocket                  => Rocket
 roxterm                 => ROXTerm
 rxvt                    => rxvt
@@ -774,6 +793,9 @@ zoc                     => ZOC
 zterm                   => ZTerm
 # End terminals
 
+# The shells listed below are known or come from an internet search. The list
+# does not claim to be complete.
+
 # Begin shells
 ash
 bash
